@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef FILTERICEDOVE_H
-#define FILTERICEDOVE_H
+#pragma once
 
 #include "filterthunderbird.h"
 namespace MailImporter
@@ -28,5 +27,3 @@ protected:
     Q_REQUIRED_RESULT QString settingsPath() override;
 };
 }
-
-#endif // FILTERICEDOVE_H
